@@ -5,15 +5,17 @@ use warnings;
 
 use RxPerl::Operators::Creation ':all';
 use RxPerl::Operators::Pipeable ':all';
+use RxPerl::Functions 'last_value_from', 'first_value_from';
 
 use Exporter 'import';
 our @EXPORT_OK = (
     @RxPerl::Operators::Creation::EXPORT_OK,
     @RxPerl::Operators::Pipeable::EXPORT_OK,
+    @RxPerl::Functions::EXPORT_OK,
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.5.0";
+our $VERSION = "v6.6.0";
 
 1;
 __END__
@@ -324,8 +326,8 @@ Pipeable operators (also referred to as "operators") are passed as arguments to
 observables. Their function is to take an observable, transform it somehow, then (similar to piped shell commands) pass
 the result of the transformation to the next pipeable operator in the pipe, or return it to the user.
 
-The following list is the currently implemented operators, with links to relevant rxjs documentation (which should apply to RxPerl
-too).
+The following list is the currently implemented operators, with links to relevant rxjs documentation (which should
+apply to RxPerl too).
 
 =over
 
@@ -727,6 +729,39 @@ L<https://rxjs.dev/api/operators/withLatestFrom>
 
 =back
 
+=head2 PROMISE FUNCTIONS
+
+These functions return a promise, and require the exitence of a user-selectable promise library.
+They are borrowed from rxjs 7, and remain EXPERIMENTAL until rxjs 7 is finalized.
+
+=over
+
+=item first_value_from
+
+Accepts an observable and returns a promise that resolves with the observable's first emitted value
+as soon as it gets emitted. If no value is emitted before the observable's completion, the promise
+is rejected.
+
+    use RxPerl::IOAsync ':all';
+    RxPerl::IOAsync->set_promise_class('Promise::ES6'); # not required for RxPerl::Mojo
+
+    my $o = ...; # an observable
+    first_value_from($o)->then( ... );
+
+=item last_value_from
+
+Accepts an observable and returns a promise that resolves with the observable's last emitted value
+as soon as the observable completes. If no value is emitted before the observable's completion, the
+promise is rejected.
+
+    use RxPerl::IOAsync ':all';
+    RxPerl::IOAsync->set_promise_class('Promise::ES6'); # not required for RxPerl::Mojo
+
+    my $o = ...; # an observable
+    last_value_from($o)->then( ... );
+
+=back
+
 =head1 OBSERVABLE METHODS
 
 =over
@@ -847,7 +882,7 @@ ReactiveX to cater for web developers already familiar with rxjs.
 
 =back
 
-=head1 NOTIFICATIONS FOR NEW VERSIONS
+=head1 NOTIFICATIONS FOR NEW RELEASES
 
 You can start receiving emails for new releases of this module, at L<https://perlmodules.net>.
 
@@ -860,6 +895,6 @@ it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-KARJALA E<lt>karjala@cpan.orgE<gt>
+Alexander Karelas E<lt>karjala@cpan.orgE<gt>
 
 =cut
